@@ -246,34 +246,6 @@ class CfnFileSystem(
 
         jsii.create(CfnFileSystem, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnFileSystem":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -472,6 +444,7 @@ class CfnFileSystem(
         jsii_type="@aws-cdk/aws-fsx.CfnFileSystem.LustreConfigurationProperty",
         jsii_struct_bases=[],
         name_mapping={
+            "auto_import_policy": "autoImportPolicy",
             "automatic_backup_retention_days": "automaticBackupRetentionDays",
             "copy_tags_to_backups": "copyTagsToBackups",
             "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
@@ -487,6 +460,7 @@ class CfnFileSystem(
         def __init__(
             self,
             *,
+            auto_import_policy: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
             copy_tags_to_backups: typing.Optional[
                 typing.Union[bool, aws_cdk.core.IResolvable]
@@ -500,6 +474,7 @@ class CfnFileSystem(
             weekly_maintenance_start_time: typing.Optional[str] = None,
         ) -> None:
             """
+            :param auto_import_policy: ``CfnFileSystem.LustreConfigurationProperty.AutoImportPolicy``.
             :param automatic_backup_retention_days: ``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
             :param copy_tags_to_backups: ``CfnFileSystem.LustreConfigurationProperty.CopyTagsToBackups``.
             :param daily_automatic_backup_start_time: ``CfnFileSystem.LustreConfigurationProperty.DailyAutomaticBackupStartTime``.
@@ -514,6 +489,8 @@ class CfnFileSystem(
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html
             """
             self._values = {}
+            if auto_import_policy is not None:
+                self._values["auto_import_policy"] = auto_import_policy
             if automatic_backup_retention_days is not None:
                 self._values[
                     "automatic_backup_retention_days"
@@ -541,6 +518,15 @@ class CfnFileSystem(
                     "weekly_maintenance_start_time"
                 ] = weekly_maintenance_start_time
 
+        @builtins.property
+        def auto_import_policy(self) -> typing.Optional[str]:
+            """``CfnFileSystem.LustreConfigurationProperty.AutoImportPolicy``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html#cfn-fsx-filesystem-lustreconfiguration-autoimportpolicy
+            """
+            return self._values.get("auto_import_policy")
+
         @builtins.property
         def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
             """``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
